@@ -22,7 +22,7 @@ struct Foo {
   void *x;
 };
 
-Foo *create(std::string name) {
+Foo *create(std::string name, int max) {
   // Erase previous message queue
   message_queue::remove(name.c_str());
 
@@ -30,7 +30,7 @@ Foo *create(std::string name) {
   message_queue *mq = new message_queue(create_only // only create
                                         ,
                                         name.c_str(),
-                                        100 // max message number
+                                        max // max message number
                                         ,
                                         2220 // sizeof(int) // max message size
   );
